from __future__ import annotations

from abqpy.decorators import abaqus_class_doc

from ..UtilityAndView.abaqusConstants import SymbolicConstant
from .InteractionState import InteractionState


@abaqus_class_doc
class SurfaceToSurfaceStdState(InteractionState):
    """The SurfaceToSurfaceStdState object stores the propagating data for a SurfaceToSurfaceContactStd object.
    One instance of this object is created internally by the SurfaceToSurfaceContactStd object for each step.
    The instance is also deleted internally by the SurfaceToSurfaceContactStd object. The
    SurfaceToSurfaceStdState object has no constructor or methods. The SurfaceToSurfaceStdState object is
    derived from the InteractionState object.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].steps[name].interactionStates[name]

        The corresponding analysis keywords are:

        - CONTACT CONTROLS
        - CONTACT PAIR
        - CONTACT INTERFERENCE
    """

    #: A SymbolicConstant specifying the propagation state of the **interactionProperty** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    interactionPropertyState: SymbolicConstant

    #: A SymbolicConstant specifying the interference type. Possible values are NONE,
    #: SHRINK_FIT, and UNIFORM.
    interferenceType: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **interferenceType** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    interferenceTypeState: SymbolicConstant

    #: A Float specifying the allowable overclosure.
    overclosure: float | None = None

    #: A SymbolicConstant specifying the propagation state of the **overclosure** member.
    #: Possible values are COMPUTED and DIRECTION_COSINE.
    overclosureState: SymbolicConstant

    #: A SymbolicConstant specifying the interference direction type. Possible values are
    #: COMPUTED and DIRECTION_COSINE.
    interferenceDirectionType: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **interferenceDirectionType**
    #: member. Possible values are UNSET, SET, UNCHANGED, and FREED.
    interferenceDirectionTypeState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **direction** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    directionState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant

    #: A SymbolicConstant specifying the propagation state of the **contactControls** member.
    #: Possible values are UNSET, SET, UNCHANGED, and FREED.
    contactControlsState: SymbolicConstant

    #: A String specifying the name of the ContactProperty object associated with this
    #: interaction.
    interactionProperty: str = ""

    #: A String specifying the name of the Amplitude object that defines the magnitude of the
    #: prescribed interference during the step.
    amplitude: str = ""

    #: A String specifying the name of the ContactControl object associated with this
    #: interaction.
    contactControls: str = ""

    #: A tuple of three Floats specifying the following:
    #: - X-direction cosine of the interference direction vector.
    #: - Y-direction cosine of the interference direction vector.
    #: - Z-direction cosine of the interference direction vector.
    direction: float | None = None

    #: A SymbolicConstant specifying the propagation state of the InteractionState object.
    #: Possible values are:
    #:
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant



from __future__ import annotations

from abaqus.Job.Job import Job
from abaqus.Odb.AnalyticSurfaceSegment import AnalyticSurfaceSegment
from abaqus.Odb.HistoryPoint import HistoryPoint
from odbAccess import (
    AnalyticSurfaceProfile,
    Odb,
    isUpgradeRequiredForOdb,
    openOdb,
    upgradeOdb,
)

# from odbAccess import closeOdb
# from odbAccess import truncateOdb

__all__ = [
    "Job",
    "AnalyticSurfaceSegment",
    "HistoryPoint",
    "AnalyticSurfaceProfile",
    "Odb",
    "isUpgradeRequiredForOdb",
    "openOdb",
    "upgradeOdb",
    # "closeOdb",
    # "truncateOdb",
]



from __future__ import annotations

from .AFXCommand import AFXCommand
from .AFXKeyword import AFXKeyword
from .constants import INT_DEFAULT


class AFXIntKeyword(AFXKeyword):
    """Abaqus."""

    def __init__(
        self,
        command: AFXCommand,
        name: str,
        isRequired: bool = False,
        defaultValue: int = INT_DEFAULT,
        evalExpression: bool = True,
    ):
        """Constructor.

        Parameters
        ----------
        command : AFXCommand
            Host command.
        name : str
            Keyword name.
        isRequired : bool
            True if the keyword is a required argument of the command.
        defaultValue : int
            Default value.
        evalExpression : bool
            True if the keyword supports expression evaluation.
        """

    def getTypeName(self):
        """Returns the name of the keyword type.

        Implements AFXKeyword. Reimplemented in AFXSymConstKeyword.
        """

    def getValue(self):
        """Returns the keyword's current value."""

    def getValueAsString(self):
        """Returns the text string that represents the keyword's current value.

        Implements AFXKeyword. Reimplemented in AFXSymConstKeyword.
        """

    def isValueChanged(self):
        """Returns True if the keyword value differs from its previous value.

        Implements AFXKeyword.
        """

    def setDefaultValue(self, defaultValue: int):
        """Sets the keyword's default value.

        Parameters
        ----------
        defaultValue : int
            Default value.
        """

    def setValue(self, newValue: int):
        """Sets the keyword's current value.

        Parameters
        ----------
        newValue : int
            New value.
        """

    def setValueToDefault(self, ignoreUnspecified: bool = False):
        """Sets the keyword value to its default.

        Parameters
        ----------
        ignoreUnspecified : bool
            Ignore setting the value if the default is unspecified.
        """

    def setValueToPrevious(self):
        """Sets the keyword value to its previous value.

        Implements AFXKeyword.
        """

    def syncPreviousValue(self):
        """Sets the keyword's previous value to its current value.

        Implements AFXKeyword. By clicking on Send, you accept that Dassault Systèmes will process your
        personal data and may contact you for further information. [Privacy Policy](
        https://www.3ds.com/privacy-policy).
        Total Results: Results per page This page cannot be found. The page might not exist or is
        temporarily unavailable. Try again or try searching for the topic. Use this form to provide feedback
        on this help topic. To get product support or to provide product feedback, go to [Frequently Asked
        Questions](
        https://3ds.one/PO).
        For support for online purchased solutions, go to [Online Purchase Support](https://3ds.one/Q8). *
        Required Subject: Feedback on User Assistance * I acknowledge I have read and I hereby accept the
        [privacy policy](
        https://www.3ds.com/privacy-policy)
        under which my personal data will be used by Dassault Systèmes.
        """



from __future__ import annotations

from .AFXCommand import AFXCommand
from .AFXKeyword import AFXKeyword

#: Any type is accepted.
AFXTABLE_TYPE_ANY: int = hash("AFXTABLE_TYPE_ANY")

#: Column type is the same as the table default type.
AFXTABLE_TYPE_DEFAULT: int = hash("AFXTABLE_TYPE_DEFAULT")

#: Column stores integer numbers.
AFXTABLE_TYPE_INT: int = hash("AFXTABLE_TYPE_INT")

#: Column stores floating-point numbers.
AFXTABLE_TYPE_FLOAT: int = hash("AFXTABLE_TYPE_FLOAT")

#: Column stores string values.
AFXTABLE_TYPE_STRING: int = hash("AFXTABLE_TYPE_STRING")

#: Column stores True or False.
AFXTABLE_TYPE_BOOL: int = hash("AFXTABLE_TYPE_BOOL")

#: Mask for column types.
AFXTABLE_TYPE_MASK: int = hash("AFXTABLE_TYPE_MASK")

#: Allow empty values for the column elements.
AFXTABLE_ALLOW_EMPTY: int = hash("AFXTABLE_ALLOW_EMPTY")

#: Always substitute the default for empty values.
AFXTABLE_DEFAULT_IF_EMPTY: int = hash("AFXTABLE_DEFAULT_IF_EMPTY")

#: Evaluate integer and float elements.
AFXTABLE_EVALUATE: int = hash("AFXTABLE_EVALUATE")

#: Use table default column style.
AFXTABLE_STYLE_DEFAULT: int = hash("AFXTABLE_STYLE_DEFAULT")

#: Mask for column styles.
AFXTABLE_STYLE_MASK: int = hash("AFXTABLE_STYLE_MASK")


class AFXComTableKeyword(AFXKeyword):
    """This class manages values which are sent as tables in a command."""

    #: ID for AFXTable widgets.
    ID_TABLE: int = hash("ID_TABLE")

    #: ID for widgets exchanging array strings.
    ID_VALUE: int = hash("ID_VALUE")

    #: For debugging.
    ID_PRINTSNIPPET: int = hash("ID_PRINTSNIPPET")

    def __init__(
        self,
        command: AFXCommand,
        name: str,
        isRequired: bool = False,
        minLength: int = 0,
        maxLength: int = -1,
        opts: int = 0,
    ):
        """Constructor.

        Parameters
        ----------
        command : AFXCommand
            Host command.
        name : str
            Keyword name.
        isRequired : bool
            True if this keyword is a required argument.
        minLength : int
            Minimum (and default) row length.
        maxLength : int
            Maximum row length (-1 => unlimited).
        opts : int
            Options.
        """

    def equal(self, index: int, a: str, b: str):
        """Returns True if the two table element values compare equal (index not used).

        Parameters
        ----------
        index : int
            Element index (not used).
        a : str
            First value.
        b : str
            Second value.
        """

    def getColumnStyle(self, index: int):
        """Returns the style of the column elements. Will never return AFXTABLE_STYLE_DEFAULT!

        Parameters
        ----------
        index : int
            Column index.
        """

    def getColumnType(self, index: int):
        """Returns the type of the column elements. Will never return AFXTABLE_TYPE_DEFAULT!

        Parameters
        ----------
        index : int
            Column index.
        """

    def getDefaultStyle(self):
        """Returns the default style for the table elements."""

    def getDefaultType(self):
        """Returns the default type for the table elements."""

    def getDefaultValues(self):
        """Returns the default values for this table."""

    def getFormattedValue(self, row: int, column: int):
        """Returns the formatted value of the table element, suitable for placing in a command. If the element
        has AFXTABLE_EVALUATE style, and its contents are invalid, an exception will be thrown.

        Parameters
        ----------
        row : int
            Row index.
        column : int
            Column index.
        """

    def getMaxNumColumns(self):
        """Returns the maximum number of columns, or -1 for unbounded."""

    def getMinNumColumns(self):
        """Returns the minimum number of columns."""

    def getNumColumns(self, row: int):
        """Returns the number of columns in the row.

        Parameters
        ----------
        row : int
            Row index.
        """

    def getNumRows(self):
        """Returns the number of rows in the table."""

    def getRow(self, row: int):
        """Returns a string with the contents of a table row.

        Parameters
        ----------
        row : int
            Row index.
        """

    def getTypeName(self):
        """Returns the name of the table keyword type.

        Implements AFXKeyword. Reimplemented in AFXTableKeyword.
        """

    def getValue(self, row: int, column: int):
        """Returns the value of a table element.

        Parameters
        ----------
        row : int
            Row index.
        column : int
            Column index.
        """

    def getValueAsDouble(self):
        """Returns the keyword's value as a float; returns False upon failure."""

    def getValueAsInt(self):
        """Returns the keyword's value as an integer; returns False upon failure."""

    def getValueAsString(self):
        """Returns the formatted string that represents the current keyword value in a command.

        Implements AFXKeyword.
        """

    def getValueForBlank(self, column: int):
        """Returns the element value substituted for blank for the column.

        Parameters
        ----------
        column : int
            Column index.
        """

    def getValues(self):
        """Returns a string containing values of the tuple elements.

        as entered by the user.
        """

    def getValuesForBlanks(self):
        """Returns a string with values substituted for blanks for all table columns."""

    def insertColumns(self, index: int, numColumns: int):
        """Inserts columns starting at the given index.

        Parameters
        ----------
        index : int
            Starting index.
        numColumns : int
            Number of columns to insert.
        """

    def insertRows(self, index: int, numRows: int):
        """Inserts rows starting at the given index.

        Parameters
        ----------
        index : int
            Starting index.
        numRows : int
            Number of rows to insert.
        """

    def isValueChanged(self):
        """Returns True if the keyword value differs from its previous value.

        Implements AFXKeyword.
        """

    def removeColumns(self, index: int, numColumns: int):
        """Removes columns starting at the given index.

        Parameters
        ----------
        index : int
            Starting index.
        numColumns : int
            Number of columns to remove.
        """

    def removeRows(self, index: int, numRows: int):
        """Removes rows starting at the given index.

        Parameters
        ----------
        index : int
            Starting index.
        numRows : int
            Number of rows to remove.
        """

    def setColumnStyle(self, index: int, style: int):
        """Sets the style of the column elements.

        Parameters
        ----------
        index : int
            Column index.
        style : int
            New column style.
        """

    def setColumnType(self, index: int, type: int):
        """Sets the type of the column elements.

        Parameters
        ----------
        index : int
            Column index.
        type : int
            New column type.
        """

    def setDefaultStyle(self, style: int):
        """Sets the default style for the table elements.

        Parameters
        ----------
        style : int
            New default style.
        """

    def setDefaultType(self, type: int):
        """Sets the default type for table elements.

        Parameters
        ----------
        type : int
            New default type.
        """

    def setDefaultValues(self, values: str):
        """Sets the default values for this table.

        Parameters
        ----------
        values : str
            Sequence string with default values.
        """

    def setMaxNumColumns(self, length: int):
        """Sets the maximum number of columns.

        Parameters
        ----------
        length : int
            New maximum number of columns, or -1 for unbounded.
        """

    def setMinNumColumns(self, length: int):
        """Sets the minimum number of columns.

        Parameters
        ----------
        length : int
            New minimum length.
        """

    def setNumColumnsRange(self, minLength: int, maxLength: int):
        """Sets the allowable range for the number of columns.

        Parameters
        ----------
        minLength : int
            New minimum number of columns.
        maxLength : int
            New maximum number of columns, or -1 for unbounded.
        """

    def setRow(self, row: int, seq: str):
        """Sets the contents of a table row.

        Parameters
        ----------
        row : int
            Row index.
        seq : str
            Sequence with elements.
        """

    def setValue(self, row: int, column: int, value: str):
        """Sets the value of a table element.

        Parameters
        ----------
        row : int
            Row index.
        column : int
            Column index.
        value : str
            New value.
        """

    def setValueForBlank(self, column: int, value: str):
        """Sets the element value substituted for blank for the column.

        Parameters
        ----------
        column : int
            Column index.
        value : str
            New value.
        """

    def setValues(self, values: str):
        """Sets all values for the table elements.

        Parameters
        ----------
        values : str
            Table string with new values.
        """

    def setValuesForBlanks(self, values: str):
        """Sets the values substituted for blanks for all table columns.

        Parameters
        ----------
        values : str
            String containing comma-separated values.
        """

    def setValueToDefault(self, ignoreUnspecified: bool = False):
        """Sets the keyword value to its default.

        Parameters
        ----------
        ignoreUnspecified : bool
            Should ignore if default is an unspecified value.
        """

    def setValueToPrevious(self):
        """Sets the keyword value to its previous value.

        Implements AFXKeyword.
        """

    def syncPreviousValue(self):
        """Sets the keyword's previous value to its current value.

        Implements AFXKeyword.
        """



from abqpy.decorators import abaqus_function_doc

from ..UtilityAndView.abaqusConstants import Boolean

"""The Python module redentABQ is a wrapper around the Python redent module. The module 
makes the indentation in a Python text file consistent. 
The module can be run as a script from a command prompt using the following statement: 
abaqus Python -m redentABQ [options] pathToFile 
where the following options are available to customize the redentABQ process: 
- `-b`: Create a backup of the selected file if any modifications are made. 
- `-i`: Specify a number of spaces to be used for indentation. 
- `-t`: Test the newly indented file after any changes are made. 
For more information on running the **abaqus Python** execution procedure, see Python 
execution. 

.. note::

    Theses functions can be accessed by::

        import redentABQ

"""


@abaqus_function_doc
def indentFile(path: str, indent: str = "", backup: Boolean = False, runTest: Boolean = False):
    """This method outputs the indented file to the terminal window or backs up the specified file and replaces
    it.

    Parameters
    ----------
    path
        A String specifying the file to be processed.
    indent
        A String specifying the amount of indentation to be used. The default value is four
        spaces of indentation. Custom indentation strings must be flanked by quotation marks ("
        ").
    backup
        A Boolean specifying whether to back up the file specified in the **path** argument if
        changes are made. The default value is False.
    runTest
        A Boolean specifying whether to test the newly indented file to ensure that it is
        semantically the same after any changes. The default value is False.

    Returns
    -------
    Boolean
        A Boolean. True, if the indentation is successful; otherwise, False.
    """
    ...



from __future__ import annotations

from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import (
    COEFFICIENTS,
    FRACTION,
    OFF,
    PENALTY,
    Boolean,
    SymbolicConstant,
)
from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class TangentialBehavior:
    """The TangentialBehavior object specifies tangential behavior for a connector friction behavior option.

    .. note::
        This object can be accessed by::

            import section
            mdb.models[name].sections[name].behaviorOptions[i].tangentialBehavior
            import odbSection
            session.odbs[name].sections[name].behaviorOptions[i].tangentialBehavior

        The table data for this object are:

        - If **formulation** = PENALTY, the table data specify the following:

            - Friction coefficient in the slip direction, μμ.
            - Slip rate, if the data depend on slip rate.
            - Contact pressure, if the data depend on contact pressure.
            - Temperature, if the data depend on temperature.
            - Value of the first field variable, if the data depend on field variables.
            - Value of the second field variable.
            - Etc.
        - If **formulation** = EXPONENTIAL_DECAY and **exponentialDecayDefinition** = COEFFICIENTS, the table data specify the following:

            - Static friction coefficient, μsμs.
            - Kinetic friction coefficient, μkμk.
            - Decay coefficient, dcdc.
        - If **formulation** = EXPONENTIAL_DECAY and **exponentialDecayDefinition** = TEST_DATA, the table data specify the following:

            - Static coefficient of friction.
            - Dynamic friction coefficient measured at the reference slip rate, ˙γ2γ˙2.
            - Reference slip rate, ˙γ2γ˙2, used to measure the dynamic friction coefficient.
            - Kinetic friction coefficient, μ∞μ∞. This value corresponds to the asymptotic value of the friction coefficient at infinite slip rate, ˙γ∞γ˙∞.

        The corresponding analysis keywords are:

        - FRICTION
    """

    #: A SymbolicConstant specifying the friction coefficient formulation. Possible values are
    #: PENALTY and EXPONENTIAL_DECAY. The default value is PENALTY.
    formulation: SymbolicConstant = PENALTY

    #: A Boolean specifying whether the data depend on slip rate. The default value is OFF.
    slipRateDependency: Boolean = OFF

    #: A Boolean specifying whether the data depend on contact pressure. The default value is
    #: OFF.
    pressureDependency: Boolean = OFF

    #: A Boolean specifying whether the data depend on temperature. The default value is OFF.
    temperatureDependency: Boolean = OFF

    #: An Int specifying the number of field variables for the data. The default value is 0.
    dependencies: int = 0

    #: A SymbolicConstant specifying the exponential decay definition for the data. Possible
    #: values are COEFFICIENTS and TEST_DATA. The default value is COEFFICIENTS.
    exponentialDecayDefinition: SymbolicConstant = COEFFICIENTS

    #: None or a Float specifying no upper limit or the friction coefficient shear stress
    #: limit. The default value is None.
    shearStressLimit: float | None = None

    #: A SymbolicConstant specifying the method for modifying the allowable elastic slip.
    #: Possible values are FRACTION and ABSOLUTE_DISTANCE. The default value is FRACTION.This
    #: argument applies only to Abaqus/Standard analyses.
    maximumElasticSlip: SymbolicConstant = FRACTION

    #: A Float specifying the ratio of the allowable maximum elastic slip to a characteristic
    #: model dimension. The default value is 10⁻⁴.This argument applies only to Abaqus/Standard
    #: analyses.
    fraction: float | None = None

    #: None or a Float specifying the absolute magnitude of the allowable elastic slip. The
    #: default value is None.This argument applies only to Abaqus/Standard analyses.
    absoluteDistance: float | None = None

    #: A sequence of sequences of Floats specifying the tangential properties. Items in the
    #: table data are described below. The default value is an empty sequence.
    table: tuple = ()

    @abaqus_method_doc
    def __init__(
        self,
        formulation: Literal[C.PENALTY, C.EXPONENTIAL_DECAY] = PENALTY,
        slipRateDependency: Boolean = OFF,
        pressureDependency: Boolean = OFF,
        temperatureDependency: Boolean = OFF,
        dependencies: int = 0,
        exponentialDecayDefinition: Literal[C.TEST_DATA, C.COEFFICIENTS] = COEFFICIENTS,
        shearStressLimit: float | None = None,
        maximumElasticSlip: Literal[C.FRACTION, C.ABSOLUTE_DISTANCE] = FRACTION,
        fraction: float | None = None,
        absoluteDistance: float | None = None,
        table: tuple = (),
    ):
        """This method creates a TangentialBehavior object.

        .. note::
            This function can be accessed by::

                mdb.models[name].sections[name].behaviorOptions[i].TangentialBehavior
                session.odbs[name].sections[name].behaviorOptions[i].TangentialBehavior

        Parameters
        ----------
        formulation
            A SymbolicConstant specifying the friction coefficient formulation. Possible values are
            PENALTY and EXPONENTIAL_DECAY. The default value is PENALTY.
        slipRateDependency
            A Boolean specifying whether the data depend on slip rate. The default value is OFF.
        pressureDependency
            A Boolean specifying whether the data depend on contact pressure. The default value is
            OFF.
        temperatureDependency
            A Boolean specifying whether the data depend on temperature. The default value is OFF.
        dependencies
            An Int specifying the number of field variables for the data. The default value is 0.
        exponentialDecayDefinition
            A SymbolicConstant specifying the exponential decay definition for the data. Possible
            values are COEFFICIENTS and TEST_DATA. The default value is COEFFICIENTS.
        shearStressLimit
            None or a Float specifying no upper limit or the friction coefficient shear stress
            limit. The default value is None.
        maximumElasticSlip
            A SymbolicConstant specifying the method for modifying the allowable elastic slip.
            Possible values are FRACTION and ABSOLUTE_DISTANCE. The default value is FRACTION.This
            argument applies only to Abaqus/Standard analyses.
        fraction
            A Float specifying the ratio of the allowable maximum elastic slip to a characteristic
            model dimension. The default value is 10⁻⁴.This argument applies only to Abaqus/Standard
            analyses.
        absoluteDistance
            None or a Float specifying the absolute magnitude of the allowable elastic slip. The
            default value is None.This argument applies only to Abaqus/Standard analyses.
        table
            A sequence of sequences of Floats specifying the tangential properties. Items in the
            table data are described below. The default value is an empty sequence.

        Returns
        -------
        TangentialBehavior
            A TangentialBehavior object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the TangentialBehavior object."""
        ...



from __future__ import annotations

from .constants import DEFAULT_PAD
from .FXColor import FXColor
from .FXComposite import FXComposite
from .FXWindow import FRAME_NORMAL, FXWindow

#: Default justification is centered text.
JUSTIFY_NORMAL: int = hash("JUSTIFY_NORMAL")

#: Contents centered horizontally.
JUSTIFY_CENTER_X: int = hash("JUSTIFY_CENTER_X")

#: Contents left-justified.
JUSTIFY_LEFT: int = hash("JUSTIFY_LEFT")

#: Contents right-justified.
JUSTIFY_RIGHT: int = hash("JUSTIFY_RIGHT")

#: Combination of JUSTIFY_LEFT & JUSTIFY_RIGHT.
JUSTIFY_HZ_APART: int = hash("JUSTIFY_HZ_APART")

#: Contents centered vertically.
JUSTIFY_CENTER_Y: int = hash("JUSTIFY_CENTER_Y")

#: Contents aligned with label top.
JUSTIFY_TOP: int = hash("JUSTIFY_TOP")

#: Contents aligned with label bottom.
JUSTIFY_BOTTOM: int = hash("JUSTIFY_BOTTOM")

#: Combination of JUSTIFY_TOP & JUSTIFY_BOTTOM.
JUSTIFY_VT_APART: int = hash("JUSTIFY_VT_APART")


class FXFrame(FXWindow):
    """Base Frame."""

    def __init__(
        self,
        p: FXComposite,
        opts: int = FRAME_NORMAL,
        x: int = 0,
        y: int = 0,
        w: int = 0,
        h: int = 0,
        pl: int = DEFAULT_PAD,
        pr: int = DEFAULT_PAD,
        pt: int = DEFAULT_PAD,
        pb: int = DEFAULT_PAD,
    ):
        """Construct frame window.

        Parameters
        ----------
        p : FXComposite

        opts : int

        x : int

        y : int

        w : int

        h : int

        pl : int

        pr : int

        pt : int

        pb : int
        """

    def getBaseColor(self):
        """Get base gui color."""

    def getBorderColor(self):
        """Get border color."""

    def getBorderWidth(self):
        """Get border width."""

    def getDefaultHeight(self):
        """Return default height.

        Reimplemented from FXWindow. Reimplemented in FXArrowButton, FXCheckButton, FXColorBar, FXColorWell,
        FXColorWheel, FXDial, FXDockTitle, FXHeader, FXLabel, FXMDIDeleteButton, FXMDIRestoreButton,
        FXMDIMaximizeButton, FXMDIMinimizeButton, FXMDIWindowButton, FXMenuButton, FXProgressBar, FXOption,
        FXOptionMenu, FXRadioButton, FXHorizontalSeparator, FXVerticalSeparator, FXSlider, FXStatusline,
        FXTextField, FXToggleButton, FXToolbarGrip, FXToolbarTab, and AFXProgressBar.
        """

    def getDefaultWidth(self):
        """Return default width.

        Reimplemented from FXWindow. Reimplemented in FXArrowButton, FXCheckButton, FXColorBar, FXColorWell,
        FXColorWheel, FXDial, FXDockTitle, FXHeader, FXLabel, FXMDIDeleteButton, FXMDIRestoreButton,
        FXMDIMaximizeButton, FXMDIMinimizeButton, FXMDIWindowButton, FXMenuButton, FXProgressBar, FXOption,
        FXOptionMenu, FXRadioButton, FXHorizontalSeparator, FXVerticalSeparator, FXSlider, FXStatusline,
        FXTextField, FXToggleButton, FXToolbarGrip, FXToolbarTab, and AFXProgressBar.
        """

    def getFrameStyle(self):
        """Get current frame style."""

    def getHiliteColor(self):
        """Get highlight color."""

    def getPadBottom(self):
        """Get bottom interior padding."""

    def getPadLeft(self):
        """Get left interior padding."""

    def getPadRight(self):
        """Get right interior padding."""

    def getPadTop(self):
        """Get top interior padding."""

    def getShadowColor(self):
        """Get shadow color."""

    def setBaseColor(self, clr: FXColor):
        """Change base gui color.

        Parameters
        ----------
        clr : FXColor
        """

    def setBorderColor(self, clr: FXColor):
        """Change border color.

        Parameters
        ----------
        clr : FXColor
        """

    def setFrameStyle(self, style: int):
        """Change frame style.

        Parameters
        ----------
        style : int
        """

    def setHiliteColor(self, clr: FXColor):
        """Change highlight color.

        Parameters
        ----------
        clr : FXColor
        """

    def setPadBottom(self, pb: int):
        """Change bottom padding.

        Parameters
        ----------
        pb : int
        """

    def setPadLeft(self, pl: int):
        """Change left padding.

        Parameters
        ----------
        pl : int
        """

    def setPadRight(self, pr: int):
        """Change right padding.

        Parameters
        ----------
        pr : int
        """

    def setPadTop(self, pt: int):
        """Change top padding.

        Parameters
        ----------
        pt : int
        """

    def setShadowColor(self, clr: FXColor):
        """Change shadow color.

        Parameters
        ----------
        clr : FXColor
        """



from __future__ import annotations

from .FXObject import FXObject


class AFXColumnItems(FXObject):
    """Abaqus."""

    def __init__(self, referenceColumn: int, tgt: FXObject | None = None, sel: int = 0, opts: int = 0):
        """Constructor for use with a keyword.

        Parameters
        ----------
        referenceColumn : int
            Index of the reference column.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        opts : int
            Selection options (not used).
        """

    def getReferenceColumn(self):
        """Returns the index of the table reference column."""

    def getSelector(self):
        """Returns the message ID."""

    def getTarget(self):
        """Returns the message target."""

    def setReferenceColumn(self, index: int):
        """Sets the table reference column, whose selected items will be sent to the target.

        Parameters
        ----------
        index : int
            Table column index.
        """

    def setSelector(self, sel: int):
        """Sets the message ID.

        Parameters
        ----------
        sel : int
            New message ID.
        """

    def setTarget(self, tgt: FXObject):
        """Sets the message target.

        Parameters
        ----------
        tgt : FXObject
            New message target.
        """



from typing_extensions import Literal

from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import abaqusConstants as C


@abaqus_class_doc
class MasterSlaveAssignment:
    """The MasterSlaveAssignment object stores the master-slave assignment definition for surfaces in ContactExp
    and ContactStd objects. The MasterSlaveAssignment object has no constructor or members.

    .. note::
        This object can be accessed by::

            import interaction
            mdb.models[name].interactions[name].masterSlaveAssignments

        The corresponding analysis keywords are:

        - CONTACT FORMULATION
    """

    @abaqus_method_doc
    def changeValuesInStep(self, stepName: str, index: int, value: Literal[C.BALANCED, C.SECONDARY, C.MAIN]):
        """This method allows modification of master-slave assignments already defined on surface pairs in a
        given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the master-slave assignments are to
            be modified.
        index
            An Int specifying the position of the master-slave assignment whose value is to be
            modified.
        value
            A SymbolicConstant specifying the value of the master-slave role to be assigned to the
            surface whose index is referenced. Possible values are MAIN, SECONDARY, and BALANCED.
            The SymbolicConstant BALANCED can be specified only in an Abaqus/Standard analysis.
        """
        ...

    @abaqus_method_doc
    def appendInStep(self, stepName: str, assignments: Literal[C.BALANCED, C.SECONDARY, C.MAIN, C.GLOBAL]):
        """This method allows addition of master-slave assignments to new surface pairs in a given step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the master-slave assignments are to
            be defined.
        assignments
            A sequence of tuples specifying the master-slave assignments. Each tuple contains two
            entries:

            - A region object or the SymbolicConstant GLOBAL specifying the surface to which the
              master-slave attribute is assigned.
            - A SymbolicConstant specifying the overriding master-slave value to be used for the
              first surface. Possible values of the SymbolicConstant are MAIN, SECONDARY, and
              BALANCED. The SymbolicConstant BALANCED can be specified only in an Abaqus/Standard
              analysis.
        """
        ...

    @abaqus_method_doc
    def delete(self, indices: tuple):
        """The delete method allows you to delete existing master-slave assignments.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each master-slave assignment to delete.
        """
        ...



from __future__ import annotations

from .FXComposite import FXComposite
from .FXIcon import FXIcon
from .FXMenuTitle import FXMenuTitle
from .FXPopup import FXPopup


class AFXMenuTitle(FXMenuTitle):
    """This class provides the interface for creating an FXMenuTitle and performing various management
    activities on it.

    It will use utility methods so the menu title is correctly managed for modules and procedure toolsets.
    """

    def __init__(self, parent: FXComposite, label: str, ic: FXIcon | None = None, popup: FXPopup | None = None):
        """Constructor that takes a parent.

        Parameters
        ----------
        parent : FXComposite
            Parent widget.
        label : str
            Label string.
        ic : FXIcon | None
            Icon.
        popup : FXPopup | None
            Pulldown menu.
        """

    def getOwner(self):
        """Returns the owner of the menu title.

        Reimplemented from FXWindow.
        """

    def hide(self):
        """Hides the widget.

        Reimplemented from FXWindow.
        """

    def show(self):
        """Shows the widget.

        Reimplemented from FXWindow.
        """



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ..UtilityAndView.abaqusConstants import ON, Boolean


@abaqus_class_doc
class MemoryReductionOptions:
    """The MemoryReductionOptions object controls the default settings that Abaqus/CAE uses for running in
    reduced memory mode. The MemoryReductionOptions object has no constructor. Abaqus creates the
    **MemoryReductionOptions** member when a session is started.

    .. note::
        This object can be accessed by::

            session.memoryReductionOptions
    """

    @abaqus_method_doc
    def setValues(self, reducedMemoryMode: Boolean = ON, percentThreshold: float = 75):
        """This method modifies the MemoryReductionOptions object.

        Parameters
        ----------
        reducedMemoryMode
            A Boolean specifying whether Abaqus/CAE should run in reduced memory mode. The default
            value is ON.
        percentThreshold
            A Float specifying the percent of **kernelMemoryLimit** at which the reduced memory mode
            starts. The default value is 75.0.
        """
        ...



from __future__ import annotations

from .AFXBoolKeyword import AFXBoolKeyword
from .AFXDialog import AFXDialog
from .AFXIntTarget import AFXIntTarget
from .AFXStringTarget import AFXStringTarget
from .FXObject import FXObject
from .FXWindow import FXWindow

#: A single file, existing or not (to save to).
AFXSELECTFILE_ANY: int = hash("AFXSELECTFILE_ANY")


class AFXFileDialog(AFXDialog):
    """AFXFileDialog."""

    def __init__(
        self,
        title: str,
        pathNameTgt: AFXStringTarget,
        readOnlyKw: AFXBoolKeyword,
        tgt: FXObject | None = None,
        sel: int = 0,
        mode: int = AFXSELECTFILE_ANY,
        patterns: str = "*",
        patternIndexTgt: AFXIntTarget | None = None,
    ):
        """Constructor that creates a dialog box that always occludes the main window when overlapping with the
        main window. The constructor expects a string target for storing the selected file name. If the dialog
        box allows multiple selection, the string target contains comma-separated path names of all selected
        files.

        Parameters
        ----------
        title : str
            Dialog title.
        pathNameTgt : AFXStringTarget
            Path name target.
        readOnlyKw : AFXBoolKeyword
            Read-only keyword.
        tgt : FXObject | None
            Message target.
        sel : int
            Message ID.
        mode : int
            File selection mode.
        patterns : str
            File filter patterns.
        patternIndexTgt : AFXIntTarget | None
            Index used to select a file filter pattern when the dialog box is posted.
        """

    def getCurrentPattern(self):
        """Returns the current pattern number."""

    def getDirectory(self):
        """Returns the current directory."""

    def getFileBoxStyle(self):
        """Return file list style."""

    def getFilename(self):
        """Returns the file name."""

    def getFilenames(self):
        """Returns an empty-string terminated list of selected file names, or 0 if none is selected."""

    def getItemSpace(self):
        """Returns the inter-item spacing (in pixels)."""

    def getPattern(self):
        """Returns the file pattern."""

    def getPatternList(self):
        """Returns the list of patterns."""

    def getPatternText(self, patno: int):
        """Returns the pattern text for a given pattern number.

        Parameters
        ----------
        patno : int
        """

    def getPressedButtonId(self):
        """Returns the ID of the button that the user pressed in the dialog box."""

    def getReadOnly(self):
        """Returns the read-only state."""

    def getReadOnlyPatterns(self):
        """Returns the patterns that force the enabling of the read-only button."""

    def getSelectMode(self):
        """Returns the file selection mode."""

    def setCurrentPattern(self, n: int):
        """Sets the current active pattern.

        Parameters
        ----------
        n : int
        """

    def setDirectory(self, path: str):
        """Sets the current directory.

        Parameters
        ----------
        path : str
        """

    def setFileBoxStyle(self, style: int):
        """Sets the file list style.

        Parameters
        ----------
        style : int
        """

    def setFilename(self, path: str):
        """Sets the file name.

        Parameters
        ----------
        path : str
        """

    def setItemSpace(self, s: int):
        """Sets the inter-item spacing (in pixels).

        Parameters
        ----------
        s : int
        """

    def setPattern(self, ptrn: str):
        """Sets the file pattern.

        Parameters
        ----------
        ptrn : str
        """

    def setPatternList(self, patterns: str):
        """Sets the list of file patterns.

        Parameters
        ----------
        patterns : str
        """

    def setPatternListMaxVisible(self, maxVisible: int):
        """Sets the maximum number of visible items for the file pattern list.

        Parameters
        ----------
        maxVisible : int
        """

    def setPatternText(self, patno: int, text: str):
        """Sets the pattern text for a pattern number.

        Parameters
        ----------
        patno : int

        text : str
        """

    def setReadOnly(self, state: bool):
        """Sets the initial state of read-only button.

        Parameters
        ----------
        state : bool
        """

    def setReadOnlyPatterns(self, patterns: str):
        """Sets the patterns that force the display of the read-only button; separate the entries by a newline
        character .

        Parameters
        ----------
        patterns : str
        """

    def setSelectMode(self, mode: int):
        """Sets the file selection mode.

        Parameters
        ----------
        mode : int
        """

    def show(self):
        """Posts the dialog box.

        Reimplemented from AFXDialog.
        """

    def showModal(self, occludedWindow: FXWindow | None = None):
        """Posts the dialog box as a modal dialog box. The dialog box is centered against the given widget or
        its owner widget if 0 is given.

        Parameters
        ----------
        occludedWindow : FXWindow | None
            Widget to be occluded (0 for the owner widget).
        """

    def shownReadOnly(self):
        """Returns True if the read-only button is shown."""

    def showReadOnly(self, show: bool):
        """Shows the read-only button.

        Parameters
        ----------
        show : bool
        """



from abqpy.decorators import abaqus_class_doc, abaqus_method_doc

from ...UtilityAndView.abaqusConstants import OFF, Boolean


@abaqus_class_doc
class ContactArea:
    """A ContactArea object specifies a suboption of gasket thickness behavior when
    **variableUnits** = FORCE on the GasketThicknessBehavior object. The ContactArea object
    defines the contact area or contact width versus closure curves to output an average
    pressure through variable CS11.

    .. note::
        This object can be accessed by::

            import material
            mdb.models[name].materials[name].gasketThicknessBehavior.contactArea
            import odbMaterial
            session.odbs[name].materials[name].gasketThicknessBehavior.contactArea

        The table data for this object are:

        - Contact area or width; this value must be positive.
        - Closure; this value must be positive.
        - Temperature, if the data depend on temperature.
        - Value of the first field variable, if the data depend on field variables.
        - Value of the second field variable.
        - Etc.

        The corresponding analysis keywords are:

        - GASKET CONTACT AREA
    """

    @abaqus_method_doc
    def __init__(self, table: tuple, temperatureDependency: Boolean = OFF, dependencies: int = 0):
        """This method creates a ContactArea object.

        .. note::
            This function can be accessed by::

                mdb.models[name].materials[name].gasketThicknessBehavior.ContactArea
                session.odbs[name].materials[name].gasketThicknessBehavior.ContactArea

        Parameters
        ----------
        table
            A sequence of sequences of Floats specifying the items described below.
        temperatureDependency
            A Boolean specifying whether contact area data depend on temperature. The default value
            is OFF.
        dependencies
            An Int specifying the number of field variable dependencies included in the definition
            of the contact area data, in addition to temperature. The default value is 0.

        Returns
        -------
        ContactArea
            A ContactArea object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the ContactArea object."""
        ...
